/**
  ******************************************************************************
  * @file     TIMER_CFG.c
  * @author   sinomcu.com-AE
  * @brief    Timer basic config
  *    
  *          This file provides functions to Timer basic config:
  *             Timer1 UIF set 10ms,for ADC Tigger.
  *         
  ******************************************************************************
  * @attention 
  *                           DISCLAIMER
  * The present firmware which is for guidance only aims at providing customers
  * with coding information regarding their products in order for them to save
  * time. As a result, sinomcu.com shall not be held liable for any direct,indirect
  * or consequential damages with respect to any claims arising from the content 
  * of such firmware and/or the use made by customers of the coding information 
  * contained herein in connection with their products.
  *
  * <h2><center>&copy; Copyright (c) 2021 sinomcu.com All rights reserved.</center></h2>
  *
  ******************************************************************************
  */
#include "user_config.h"    
#include "TIMER_CFG.h"
/**
  * @brief  Timer Initialization for ADC Trigger Function
  * @param  None
  * @retval None
  */
void timer_init(void) {
  MS32_TIM_InitTypeDef TimerInitStruct = {0};
  
  // timer 100ms,Trig to ADC
  MS32_TIM_StructInit(&TimerInitStruct);
  TimerInitStruct.CounterMode =MS32_TIM_COUNTERMODE_UP;
  TimerInitStruct.Prescaler   = __MS32_TIM_CALC_PSC(SystemCoreClock,1000);                         // unit Hz,div sysclk to  CNT clk:1khz           
  TimerInitStruct.Autoreload  = __MS32_TIM_CALC_ARR(SystemCoreClock,TimerInitStruct.Prescaler,100); // unit Hz,100Hz(10ms)
  TimerInitStruct.RepetitionCounter = 0;                  
  MS32_TIM_Init(TIM1, &TimerInitStruct);                   // init function had enable clock

  MS32_TIM_SetClockSource(TIM1, MS32_TIM_CLOCKSOURCE_INTERNAL);           // clk form RCC:PCLK <-- AHP_RRE=1,sysclk <-- HSI8M or PLL
  MS32_TIM_EnableARRPreload(TIM1);
  MS32_TIM_DisableMasterSlaveMode(TIM1);                                  // disable the Master/Slave mode.

  MS32_TIM_SetTriggerOutput(TIM1, MS32_TIM_TRGO_UPDATE);
  MS32_TIM_EnableCounter(TIM1);                                           // start timer 
}

/******************************** END OF FILE *********************************/
